package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.auth.feign.AuthFeign;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.User;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * @Author：蓬叁
 * @Package：com.bwie.auth.service.impl
 * @Project：maven-day13-exam
 * @name：AuthServiceImpl
 * @Date：2024/8/1 上午8:57
 */
@Service
public class AuthServiceImpl implements AuthService {

    @Autowired private AuthFeign authFeign;
    @Autowired private RedisTemplate redisTemplate;

    @Override
    public Result<JwtResponse> login(User user) {
        if (null == user.getUserName() || null == user.getUserPwd()){
            return Result.error("账号 或 密码不能为空");
        }
        Result<User> byName = authFeign.findByName(user.getUserName());
        User data = byName.getData();
        if (null == data){
            return Result.error("账号不存在");
        }
        if (!user.getUserPwd().equals(data.getUserPwd())){
            return Result.error("密码错误");
        }
        Map<String, Object> map = new HashMap<>();
        String userKey = UUID.randomUUID().toString().replaceAll("-", "");
        map.put(JwtConstants.USER_KEY,userKey);
        String token = JwtUtils.createToken(map);
        redisTemplate.opsForValue().set(
                TokenConstants.LOGIN_TOKEN_KEY+userKey,
                JSONObject.toJSONString(data),
                10,
                TimeUnit.MINUTES
        );
        JwtResponse jwtResponse = new JwtResponse();
        jwtResponse.setToken(token);
        jwtResponse.setTime("10MIN");
        return Result.success(jwtResponse,"登录成功");
    }
}
